@@ -36,22 +36,30 @@ class MAEFile(File):
 
         file = MAEFile(name=name)
 
-        (geometries, symbols, bonds, p_names, p_vals, conformers) = cls._read_mae(filename, **kwargs)
+        (geometries, symbols, bonds, p_names, p_vals, conformers) = cls._read_mae(
+            filename, **kwargs
+        )
         atomic_numbers = np.array([get_number(z) for z in symbols], dtype=np.int8)
 
-        if conformers == True:
+        if conformers is True:
             file.ensemble = ConformationalEnsemble()
         else:
             file.ensemble = Ensemble()
 
         for geom in geometries:
-            file.ensemble.add_molecule(Molecule(atomic_numbers, geom, bonds=bonds.edges))
+            file.ensemble.add_molecule(
+                Molecule(atomic_numbers, geom, bonds=bonds.edges)
+            )
 
         return file, p_names, p_vals
 
     @classmethod
     def _read_mae(
-        cls, filename, contains_conformers="check", save_memory_for_conformers=True, print_status_messages=False,
+        cls,
+        filename,
+        contains_conformers="check",
+        save_memory_for_conformers=True,
+        print_status_messages=False,
     ):
         """
         Reads uncompressed Macromodel files.
@@ -99,7 +107,9 @@ class MAEFile(File):
 
             # determine if we are in a molecule block
             end_of_file = i + 1 == len(lines)
-            if current_block_type is None and (line.startswith("f_m_ct") or end_of_file):
+            if current_block_type is None and (
+                line.startswith("f_m_ct") or end_of_file
+            ):
                 # store the current results if any
                 if this_geometry is not None and len(this_geometry) > 0:
                     geometries.append(this_geometry)
@@ -123,15 +133,21 @@ class MAEFile(File):
                 if line.startswith("i_m_ct_format"):
                     next_line = lines[i].strip()
                     if next_line != ":::":
-                        raise ValueError(f"expected ':::' here but line {i+1} is:\n{next_line}\n")
+                        raise ValueError(
+                            f"expected ':::' here but line {i+1} is:\n{next_line}\n"
+                        )
                     current_block_type = "property_values"
                     i += 1
                 elif line.startswith(":::"):
-                    raise ValueError(f"expected to see i_m_ct_format as the last property (line {i+1})")
+                    raise ValueError(
+                        f"expected to see i_m_ct_format as the last property (line {i+1})"
+                    )
                 else:
                     fields = re.split(" +", line)
                     if len(fields) != 1:
-                        raise ValueError(f"unexpected number of fields in property name line: {line}")
+                        raise ValueError(
+                            f"unexpected number of fields in property name line: {line}"
+                        )
                     this_property_names.append(line)
 
             # read property values
@@ -188,11 +204,15 @@ class MAEFile(File):
                     if bond_order <= 0:
                         raise ValueError(f"zero or negative bond order: {line}")
                     if this_bonds.number_of_edges() != bond_number - 1:
-                        raise ValueError(f"non-sequential bond number (expected {this_bonds.number_of_edges()+1} but got {bond_number})")
+                        raise ValueError(
+                            f"non-sequential bond number (expected {this_bonds.number_of_edges()+1} but got {bond_number})"
+                        )
                     if this_bonds.has_edge(atom1, atom2):
                         current_bond_order = this_bonds[atom1][atom2]["weight"]
                         if current_bond_order != bond_order:
-                            raise ValueError(f"inconsistent bond order definition: {line}")
+                            raise ValueError(
+                                f"inconsistent bond order definition: {line}"
+                            )
                     this_bonds.add_edge(atom1, atom2, weight=bond_order)
                     this_bonds.add_edge(atom2, atom1, weight=bond_order)
 
@@ -207,7 +227,9 @@ class MAEFile(File):
             contains_conformers = True
             for this_symbols, this_bonds in zip(symbols[1:], bonds[1:]):
                 # must have the same symbols and bonds
-                if not (symbols[0] == this_symbols).all() or not nx.is_isomorphic(bonds[0], this_bonds):
+                if not (symbols[0] == this_symbols).all() or not nx.is_isomorphic(
+                    bonds[0], this_bonds
+                ):
                     contains_conformers = False
                     break
         elif isinstance(contains_conformers, bool):
@@ -228,7 +250,9 @@ class MAEFile(File):
                     n_atoms = len(geometries[0])
                     n_bonds = bonds.number_of_edges()
                     if print_status_messages:
-                        print(f"read {n_geometries} conformers ({n_atoms} atoms and {n_bonds} bonds).")
+                        print(
+                            f"read {n_geometries} conformers ({n_atoms} atoms and {n_bonds} bonds)."
+                        )
                 else:
                     min_n_atoms = len(geometries[0])
                     max_n_atoms = len(geometries[0])
@@ -245,7 +269,9 @@ class MAEFile(File):
                         elif this_bonds.number_of_edges() < min_n_bonds:
                             min_n_bonds = bonds.number_of_edges
                     if print_status_messages:
-                        print(f"read {n_geometries} unrelated geometries ({min_n_atoms}-{max_n_atoms} atoms and {min_n_bonds}-{max_n_bonds}) bonds).")
+                        print(
+                            f"read {n_geometries} unrelated geometries ({min_n_atoms}-{max_n_atoms} atoms and {min_n_bonds}-{max_n_bonds}) bonds)."
+                        )
             else:
                 n_atoms = len(geometries)
                 n_bonds = bonds.number_of_edges()
