@@ -1,6 +1,7 @@
 from cctk import File
 from cctk.helper_functions import get_symbol
 
+
 class PDBFile(File):
     """
     Generic class for all ``.pdb`` files.
@@ -31,14 +32,13 @@ class PDBFile(File):
             symb = get_symbol(Z).upper()
             text += f"HETATM {idx:>4}  {symb:<2}    *     0     {line[0]:7.3f} {line[1]:7.3f} {line[2]:7.3f}  1.00  0.00          {symb:>2}\n"
 
-        text += f"ENDMDL\n"
+        text += "ENDMDL\n"
 
         if append:
             super().append_to_file(filename, text)
         else:
             super().write_file(filename, text)
 
-
     @classmethod
     def write_ensemble_to_trajectory(cls, filename, ensemble):
         """
@@ -50,7 +50,8 @@ class PDBFile(File):
         """
         for idx, molecule in enumerate(ensemble.molecules):
             if idx == 0:
-                cls.write_molecule_to_file(filename, molecule, num=idx+1, append=False)
+                cls.write_molecule_to_file(
+                    filename, molecule, num=idx + 1, append=False
+                )
             else:
-                cls.write_molecule_to_file(filename, molecule, num=idx+1, append=True)
-
+                cls.write_molecule_to_file(filename, molecule, num=idx + 1, append=True)
