@@ -155,6 +155,16 @@ class TestMolecule(unittest.TestCase):
         mol = cctk.Molecule.new_from_name("acetone")
         self.assertTrue(abs(mol.volume() - 62) < 1)
 
+    def test_smiles_utils(self):
+        mol = cctk.Molecule.new_from_smiles("[OH3+]")
+        self.assertEqual(mol.charge, 1)
+
+        mol = cctk.Molecule.new_from_smiles("C1[Br+]C1(C)C")
+        self.assertEqual(mol.charge, 1)
+
+        mol = cctk.Molecule.new_from_smiles("C1[Hg+](Cl)C1(C)C")
+        self.assertEqual(mol.charge, 1)
+
     def test_renumber(self):
         mol = self.load_molecule()
         mol2 = mol.swap_atom_numbers(1, 2)
@@ -201,6 +211,9 @@ class TestMolecule(unittest.TestCase):
         mol = cctk.Molecule.new_from_name("acetic acid")
         self.assertEqual(len(mol.atomic_numbers), 8)
 
+        with self.assertRaises(ValueError):
+            mol = cctk.Molecule.new_from_smiles("CCCCCCCCCCCCCCCCCCCC", max_num_atoms=10)
+
     def test_fragment(self):
         m = cctk.GaussianFile.read_file("test/static/periodic.gjf").get_molecule()
         m = m.assign_connectivity(periodic_boundary_conditions=np.array([20, 20, 20]))
